==> haskell-enclosed-exceptions-1.0.3-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.3
id: enclosed-exceptions-1.0.3-KMG2gEGPEHs9QtH9DIrDR5
key: enclosed-exceptions-1.0.3-KMG2gEGPEHs9QtH9DIrDR5
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
author: Michael Snoyman, João Cristóvão
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
abi: 6076ef809237ec6ec3dec0ecda446230
exposed: True
exposed-modules:
    Control.Exception.Enclosed
import-dirs: /usr/lib/ghc-8.4.3/site-local/enclosed-exceptions-1.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/enclosed-exceptions-1.0.3
hs-libraries: HSenclosed-exceptions-1.0.3-KMG2gEGPEHs9QtH9DIrDR5
depends:
    base-4.11.1.0 transformers-0.5.5.0
    lifted-base-0.2.3.12-4NQhoAXDZga8XElWqeIe2X
    monad-control-1.0.2.3-LF1NHBZIRgG6fG7d7ZwfSq deepseq-1.4.3.0
    transformers-base-0.4.5.2-DJGvQweLM1lBYaWuB3tp04
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             lifted-base-0.2.3.12-4NQhoAXDZga8XElWqeIe2X=58b9a8c6dad79fba996860c72139fcdb
             monad-control-1.0.2.3-LF1NHBZIRgG6fG7d7ZwfSq=a47d843a3db6efd069d92470c607da07
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             transformers-base-0.4.5.2-DJGvQweLM1lBYaWuB3tp04=a3f67982300e89309c37d8cba5c70df6
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enclosed-exceptions-1.0.3-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.3
id: enclosed-exceptions-1.0.3-4KQPxNd6PvYIP8WpIjxhVq
key: enclosed-exceptions-1.0.3-4KQPxNd6PvYIP8WpIjxhVq
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
author: Michael Snoyman, João Cristóvão
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
abi: a7855e04d00a1015bd24b028635536a9
exposed: True
exposed-modules:
    Control.Exception.Enclosed
import-dirs: /usr/lib/ghc-8.6.1/site-local/enclosed-exceptions-1.0.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/enclosed-exceptions-1.0.3
hs-libraries: HSenclosed-exceptions-1.0.3-4KQPxNd6PvYIP8WpIjxhVq
depends:
    base-4.12.0.0 deepseq-1.4.4.0
    lifted-base-0.2.3.12-5XmRTVY8kfG4NpLmFNcXWD
    monad-control-1.0.2.3-E1ObyzwIT2xCXzhuW7Govm transformers-0.5.5.0
    transformers-base-0.4.5.2-1DiUF50wDMZ8pcSXqSIOuW
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
